@@ -1,5 +1,5 @@
 from fdsreader.utils import scan_directory_smv
-from fdsreader.simulation import Simulation
+from fdsreader import Simulation
 
 
 def main():
@@ -8,7 +8,7 @@ def main():
 
     sim = Simulation(smv_file_paths[0])
 
-    print(sim.boundaries[0].sub_boundaries[0].patches[0].data)
+    print(sim.boundaries[0]._subboundaries[0].patches[0].data)
 
 
 if __name__ == "__main__":
