@@ -2,10 +2,10 @@ from typing import Optional, Tuple
 
 
 class Surface:
-    """
-    Surface objects describe what bounding surfaces consist of. Boundary conditions for obstructions and vents are
+    """Surface objects describe what bounding surfaces consist of. Boundary conditions for obstructions and vents are
     prescribed by referencing the appropriate surface.
     TODO: Read in velocity
+
     :ivar name: Name of the surface.
     :ivar tmpm: TODO
     :ivar material_emissivity: Emissivity of the material.
